# Starburst pupil tracking algorithm

Follows the algorithm of http://bit.ly/2GmqlG7, runs offline (2Hz for 512x512)

Provides an executive "starburst", where you can select the tiff file to track. Saves the pupil radii in a numpy npy file in the same folder.
